@@ -36,6 +36,8 @@ class OAuthScopes(str, Enum):
     TRANSFERS_VIEW = 'transfers:view'
     BALANCES = 'balances'
     BALANCES_VIEW = 'balances:view'
+    REPORTING = 'reporting'
+    REPORTING_VIEW = 'reporting:view'
 
     MIDDLEWARE = 'middleware'
     MIDDLEWARE_MERCHANTS_SECRET = 'middleware:merchants-secret'
